@@ -83,7 +83,7 @@ menustruct Justifs[] = {
 	{"Middle Justified", action(setvjust, Number(NOTBOTTOM))},
 	{"Bottom Justified", setaction(setvjust, Number(NORMAL))},
 	{" ", noaction},
-	{"Flip Invariant", setaction(setflipinv, Number(FLIPINV))},
+	{"Flip Invariant", setaction(setjustbit, Number(FLIPINV))},
 };
 	
 menustruct BoxEditStyles[] = {
@@ -145,8 +145,8 @@ menustruct Colors[] = {
 };
 
 menustruct Parameterize[] = {
-	{"Substring", action(startparam, Number(P_SUBSTRING))},
-	{"Position", action(startparam, Number(P_POSITION))},
+	{"Substring", action(promptparam, NULL)},
+	{"Numeric", action(startparam, Number(P_NUMERIC))},
 	{"Style", action(startparam, Number(P_STYLE))},
 	{"Justification", action(startparam, Number(P_JUSTIFY))},
 	{"Start Angle", action(startparam, Number(P_ANGLE1))},
@@ -156,6 +156,8 @@ menustruct Parameterize[] = {
 	{"Rotation", action(startparam, Number(P_ROTATION))},
 	{"Scale", action(startparam, Number(P_SCALE))},
 	{"Linewidth", action(startparam, Number(P_LINEWIDTH))},
+	{"Color", action(startparam, Number(P_COLOR))},
+	{"Position", action(startparam, Number(P_POSITION))},
 };
 
 menustruct Stipples[] = {
@@ -180,9 +182,11 @@ menustruct TextMenu[] = {
 	{"Encoding", submenu(FontEncodings)},
 	{"Insert", submenu(TextSpacing)},             
 	{"Justification (keypad)", submenu(Justifs)},
-	{"Parameterize", action(startparam, Number(P_SUBSTRING))},
+	{"Parameterize", action(promptparam, NULL)},
 	{"Unparameterize", action(startunparam, Number(P_SUBSTRING))},
 	{" ", noaction},
+	{"Set LaTeX Mode", action(setjustbit, Number(LATEXLABEL))},
+	{" ", noaction},
 	{"Make Label (t)", action(starttext, Number(NORMAL))},
 };
 
@@ -238,7 +242,6 @@ menustruct SnapMenu[] = {
         {"Snap spacing", action(getsnapspace, NULL)},
 };
 
-#ifdef SCHEMA
 menustruct PinConvert[] = {
 	{"Normal label", action(dopintype, Number(NORMAL))},
 	{"Local Pin", action(dopintype, Number(LOCAL))},
@@ -251,19 +254,18 @@ menustruct SchemaMenu[] = {
 	{"Make Info Pin (I)", action(starttext, Number(INFO))},
 	{"Make Global Pin (G)", action(starttext, Number(GLOBAL))},
 	{"Convert Label to...", submenu(PinConvert)},
-	{"Pin Visibility", action(setpinvisible, Number(PINVISIBLE))},
+	{"Pin Visibility", action(setpinjustbit, Number(PINVISIBLE))},
 /*	{"Make Object Non-Schematic", action(maketrivial, NULL)}, */
 	{"Make Matching Symbol", action(dobeforeswap, NULL)},
 	{"Associate with Symbol", action(startschemassoc, Number(1))},
 	{"Highlight Connectivity", action(startconnect, NULL)},
-	{"Auto-number Components", action(callgennet, Number(4))},
+	{"Auto-number Components", action(callwritenet, Number(4))},
 	{" ", noaction},
-	{"Write spice", action(callgennet, Number(0))},
-	{"Write flattened spice", action(callgennet, Number(3))},
-	{"Write sim", action(callgennet, Number(1))},
-	{"Write pcb", action(callgennet, Number(2))},
+	{"Write spice", action(callwritenet, Number(0))},
+	{"Write flattened spice", action(callwritenet, Number(3))},
+	{"Write sim", action(callwritenet, Number(1))},
+	{"Write pcb", action(callwritenet, Number(2))},
 };
-#endif
 
 menustruct WindowMenu[] = {
 	{"Zoom In (Z)", action(zoominrefresh, NULL)},
@@ -284,10 +286,6 @@ menustruct FileMenu[] = {
 	{"Read Xcircuit File", action(getfile, Number(NORMAL))},
 	{"Import Xcircuit PS", action(getfile, Number(IMPORT))},
 	{"Import background PS", action(getfile, Number(PSBKGROUND))},
-#ifdef ASG
-	{"Import IVF", action(getfile, Number(IMPORTIVF))},
-	{"Import SPICE", action(getfile, Number(IMPORTSPICE))},
-#endif
 	{"Execute script", action(getfile, Number(SCRIPT))},
 	{"Write Xcircuit PS (W)", action(outputpopup, NULL)},
 	{" ", noaction},
@@ -295,7 +293,7 @@ menustruct FileMenu[] = {
 	{"Load New Library", action(getuserlib, NULL)},
 	{"Save Library", action(savelibpopup, Number(0))},
 	{" ", noaction},
-        {"Clear Page", action(resetbutton, NULL)},
+        {"Clear Page", action(resetbutton, Number(0))},
 	{" ", noaction},
 	{"Quit", action(quitcheck, NULL)},
 };
@@ -304,10 +302,8 @@ menustruct OptionMenu[] = {
 	{"Alt Colors", action(inversecolor, &areastruct.invert)},
 	{"Show Bounding box", action(toggle, &areastruct.bboxon)},
 	{"Edit in place", setaction(toggle, &areastruct.editinplace)},
-#ifdef SCHEMA
 	{"Show Pin Positions", action(toggle, &areastruct.pinpointon)},
 	{"Enable XSchema", action(doxschema, Number(1))},
-#endif
 #ifdef HAVE_XPM
 	{"Disable Toolbar", action(dotoolbar, NULL)},
 #endif
@@ -344,9 +340,7 @@ menustruct TopButtons[] = {
 	{"Text", submenu(TextMenu)},
 	{"Options", submenu(OptionMenu)},
 	{"Window", submenu(WindowMenu)},
-#ifdef SCHEMA
 	{"Netlist", submenu(SchemaMenu)},
-#endif
 };
 
 short maxbuttons = sizeof(TopButtons) / sizeof(menustruct);
